@@ -73,10 +73,43 @@ exo_die_g_key_file_set_locale_value (GKeyFile    *key_file,
 
 
 
+static void trust_launcher (GFile *gfile)
+{
+  /* trust the launcher since the user created it */
+  guint32 mode = 0111, mask = 0111;
+  guint32 old_mode, new_mode;
+  GFileInfo *info;
+
+  info = g_file_query_info (gfile,
+                            G_FILE_ATTRIBUTE_UNIX_MODE,
+                            G_FILE_QUERY_INFO_NONE,
+                            NULL,
+                            NULL);
+
+  if (info == NULL)
+    return;
+
+  old_mode = g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE);
+  new_mode = (old_mode & ~mask) | mode;
+
+  if (old_mode != new_mode) {
+    g_file_set_attribute_uint32 (gfile,
+                                 G_FILE_ATTRIBUTE_UNIX_MODE, new_mode,
+                                 G_FILE_QUERY_INFO_NONE,
+                                 NULL,
+                                 NULL);
+  }
+
+  g_object_unref (info);
+}
+
+
+
 /**
  * exo_die_g_key_file_save:
  * @key_file : the #GKeyFile.
  * @create   : whether to create.
+ * @trust    : whether to trust the launcher.
  * @base     : file or folder (if @create).
  * @mode     : file mode for .directory or .desktop suffix.
  * @error    : return location for errors or %NULL.
@@ -88,6 +121,7 @@ exo_die_g_key_file_set_locale_value (GKeyFile    *key_file,
 gboolean
 exo_die_g_key_file_save (GKeyFile          *key_file,
                          gboolean           create,
+                         gboolean           trust,
                          GFile             *base,
                          ExoDieEditorMode   mode,
                          GError           **error)
@@ -101,7 +135,6 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
   guint        n;
   gboolean     desktop_suffix;
   const gchar *suffix;
-  gchar       *path;
 
   g_return_val_if_fail (G_IS_FILE (base), FALSE);
   g_return_val_if_fail (key_file != NULL, FALSE);
@@ -121,14 +154,14 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
       g_free (name);
       if (desktop_suffix)
         {
-          file = G_FILE (g_object_ref (G_OBJECT (base)));
+          file = g_object_ref (base);
         }
       else
         {
-          file_type = g_file_query_file_type (base, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL);
+          file_type = g_file_query_file_type (base, G_FILE_QUERY_INFO_NONE, NULL);
           if (file_type == G_FILE_TYPE_REGULAR)
             {
-              file = G_FILE (g_object_ref (G_OBJECT (base)));
+              file = g_object_ref (base);
             }
           else if (file_type == G_FILE_TYPE_DIRECTORY)
             {
@@ -150,7 +183,7 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
                 {
                   /* release the previous name */
                   g_free (filename);
-                  g_object_unref (G_OBJECT (file));
+                  g_object_unref (file);
 
                   /* generate a new file name */
                   filename = g_strdup_printf ("%s%d%s", name, n, suffix);
@@ -176,37 +209,27 @@ exo_die_g_key_file_save (GKeyFile          *key_file,
   else
     {
       /* base is the file */
-      file = G_FILE (g_object_ref (G_OBJECT (base)));
+      file = g_object_ref (base);
     }
 
   /* determine the data for the key file */
   data = g_key_file_to_data (key_file, &length, error);
   if (G_UNLIKELY (data == NULL))
     {
-      g_object_unref (G_OBJECT (file));
+      g_object_unref (file);
       return FALSE;
     }
 
-  /* write the contents to the file */
-  if (g_file_is_native (file))
-    {
-      /* for local writes, to make sure the file is written to a tmp
-       * file before the origional desktop file is replaced */
-      path = g_file_get_path (file);
-      result = g_file_set_contents (path, data, length, error);
-      g_free (path);
-    }
-  else
-    {
-      /* for remote writes */
-      result = g_file_replace_contents (file, data, length, NULL, FALSE,
-                                        G_FILE_CREATE_REPLACE_DESTINATION,
-                                        NULL, NULL, error);
-    }
+  result = g_file_replace_contents (file, data, length, NULL, FALSE,
+                                    G_FILE_CREATE_NONE,
+                                    NULL, NULL, error);
+
+  if (trust)
+    trust_launcher (file);
 
   /* cleanup */
   g_free (data);
-  g_object_unref (G_OBJECT (file));
+  g_object_unref (file);
 
   return result;
 }
